<?php

namespace Drupal\synpay\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Payment Gateway Gonfig.
 */
class Settings extends ConfigFormBase {

  const CONFIG_FIELDS = [
    'active',
    'test_mode',
    'test_login',
    'test_token',
    'live_login',
    'live_token',
  ];
  const CONFIG_FIELDS_ROBOKASSA = [
    'active',
    'test_mode',
    'login',
    'live_pass',
    'live_pass2',
    'test_pass',
    'test_pass2',
    'description',
  ];

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'synpay.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'synpay_settings';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('synpay.settings');
    $manager = \Drupal::service('plugin.manager.synpay');
    foreach ($manager->getDefinitions() as $key => $source) {
      $plugins[$key] = "$key ({$source['provider']} / {$source['title']})";
    }

    foreach ($manager->getDefinitions() as $gateway => $source) {
      $label = "{$source['title']}";
      if ($source['id'] != 'robokassa') {
        $form[$gateway] = [
          '#type' => 'details',
          '#title' => $label,
          '#open' => FALSE,
          "{$gateway}_test_mode" => [
            '#type' => 'checkbox',
            '#title' => "Режим тестирования $label",
            '#default_value' => $config->get("{$gateway}_test_mode"),
          ],
          "{$gateway}_active" => [
            '#type' => 'checkbox',
            '#title' => "Платежная система $label активна",
            '#default_value' => $config->get("{$gateway}_active"),
          ],
          "{$gateway}_test_login" => [
            '#type' => 'textfield',
            '#title' => "Тестовый логин $label",
            '#maxlength' => 100,
            '#size' => 100,
            '#default_value' => $config->get("{$gateway}_test_login"),
          ],
          "{$gateway}_test_token" => [
            '#type' => 'textfield',
            '#title' => "Тестовый токен $label",
            '#maxlength' => 100,
            '#size' => 100,
            '#default_value' => $config->get("{$gateway}_test_token"),
          ],
          "{$gateway}_live_login" => [
            '#type' => 'textfield',
            '#title' => "Рабочий логин $label",
            '#maxlength' => 100,
            '#size' => 100,
            '#default_value' => $config->get("{$gateway}_live_login"),
          ],
          "{$gateway}_live_token" => [
            '#type' => 'textfield',
            '#title' => "Рабочий токен $label",
            '#maxlength' => 100,
            '#size' => 100,
            '#default_value' => $config->get("{$gateway}_live_token"),
            // '#suffix' => '<br><hr><br>',
          ],
        ];
      }
      else {
        $form[$gateway] = [
          '#type' => 'details',
          '#title' => $label,
          '#open' => FALSE,
          "{$gateway}_test_mode" => [
            '#type' => 'checkbox',
            '#title' => "Режим тестирования $label",
            '#default_value' => $config->get("{$gateway}_test_mode"),
          ],
          "{$gateway}_active" => [
            '#type' => 'checkbox',
            '#title' => "Платежная система $label активна",
            '#default_value' => $config->get("{$gateway}_active"),
          ],
          "{$gateway}_login" => [
            '#type' => 'textfield',
            '#title' => "Идентификатор магазина",
            '#maxlength' => 100,
            '#size' => 100,
            '#default_value' => $config->get("{$gateway}_login"),
          ],
          "{$gateway}_live_pass" => [
            '#type' => 'textfield',
            '#title' => "Рабочий пароль #1",
            '#maxlength' => 100,
            '#size' => 100,
            '#default_value' => $config->get("{$gateway}_live_pass"),
          ],
          "{$gateway}_live_pass2" => [
            '#type' => 'textfield',
            '#title' => "Рабочий пароль #2",
            '#maxlength' => 100,
            '#size' => 100,
            '#default_value' => $config->get("{$gateway}_live_pass2"),
          ],
          "{$gateway}_test_pass" => [
            '#type' => 'textfield',
            '#title' => "Тестовый пароль #1",
            '#maxlength' => 100,
            '#size' => 100,
            '#default_value' => $config->get("{$gateway}_test_pass"),
          ],
          "{$gateway}_test_pass2" => [
            '#type' => 'textfield',
            '#title' => "Тестовый пароль #2",
            '#maxlength' => 100,
            '#size' => 100,
            '#default_value' => $config->get("{$gateway}_test_pass2"),
          ],
          "{$gateway}_description" => [
            '#type' => 'textfield',
            '#title' => "Описание платежа (макс. 100 символов)",
            '#maxlength' => 100,
            '#size' => 100,
            '#default_value' => $config->get("{$gateway}_description"),
          ],
        ];
      }
    }
    $form['active'] = [
      '#type' => 'checkbox',
      '#title' => 'Платежная система активна (для прямой оплаты)',
      '#default_value' => $config->get('active'),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    parent::submitForm($form, $form_state);

    $config = $this->config('synpay.settings');
    $manager = \Drupal::service('plugin.manager.synpay');
    foreach ($manager->getDefinitions() as $gateway => $source) {
      if ($source['id'] != 'robokassa') {
        foreach (self::CONFIG_FIELDS as $fieldSuffix) {
          $fieldname = "{$gateway}_{$fieldSuffix}";
          $config->set($fieldname, trim($form_state->getValue($fieldname)));
        }
      }
      else {
        foreach (self::CONFIG_FIELDS_ROBOKASSA as $fieldSuffix) {
          $fieldname = "{$gateway}_{$fieldSuffix}";
          $config->set($fieldname, trim($form_state->getValue($fieldname)));
        }
      }
    }

    $config->set('active', $form_state->getValue('active'));

    $config->save();
  }

}
